@@ -374,6 +374,16 @@ pub trait GeneralReadout {
     /// Creates a new instance of the structure which implements this trait.
     fn new() -> Self;
 
+    /// This function should return the backlight (brightness) value of the machine.
+    ///
+    /// _e.g._ `100`
+    fn backlight(&self) -> Result<usize, ReadoutError> {
+        Err(STANDARD_NO_IMPL.clone())
+    }
+
+    /// This function should return the display resolution of the machine.
+    ///
+    /// _e.g. `1920x1080`
     fn resolution(&self) -> Result<String, ReadoutError> {
         Err(STANDARD_NO_IMPL.clone())
     }
@@ -450,13 +460,6 @@ pub trait GeneralReadout {
         Err(STANDARD_NO_IMPL.clone())
     }
 
-    /// This function should return a list of available GPUs. \
-    ///
-    /// _e.g._ `["NVIDIA Corporation GeForce GTX 1650 Mobile / Max-Q"]`
-    fn gpus(&self) -> Result<Vec<String>, ReadoutError> {
-        Err(STANDARD_NO_IMPL.clone())
-    }
-
     /// This function should return the average CPU usage over the last minute.
     fn cpu_usage(&self) -> Result<usize, ReadoutError> {
         Err(STANDARD_NO_IMPL.clone())
@@ -477,14 +480,14 @@ pub trait GeneralReadout {
         Err(STANDARD_NO_IMPL.clone())
     }
 
-    /// This function should return the name of the physical machine
+    /// This function should return the name of the physical machine.
     ///
     /// _e.g._ `MacBookPro11,5`
     fn machine(&self) -> Result<String, ReadoutError> {
         Err(STANDARD_NO_IMPL.clone())
     }
 
-    /// This function should return the name of the OS in a pretty format
+    /// This function should return the name of the OS in a pretty format.
     ///
     /// _e.g._ `macOS 11.2.2 Big Sur`
     fn os_name(&self) -> Result<String, ReadoutError> {
